import './trading-goods.css'
import {
  Select, DatePicker, Button, Table,
  // message,
  Space, Empty, Pagination
} from 'antd';
// import type { TableColumnsType } from 'antd';
import { SearchOutlined, ClearOutlined } from '@ant-design/icons';
import type { DatePickerProps } from 'antd';
import locale from 'antd/es/date-picker/locale/zh_CN';
import { useState } from 'react';
const { Column } = Table;
export default function TradingGoods() {
  const height = window.innerHeight - 180;
  // const [messageApi, contextHolder] = message.useMessage();
  const dateFormat = 'YYYY年MM月DD日';
  const [startTime, setStartTime] = useState<any>() //开始时间
  const [endTime, setEndTime] = useState<any>() //结束时间
  const [orderStatus, setOrderStatus] = useState<any>() //订单状态
  const [page,setPage] = useState(1) //分页
  // 更改开始时间
  const startTimeChange: DatePickerProps['onChange'] = (date, dateString) => {
    console.log(date, dateString);
    setStartTime(date)
  };
  // 更改结束时间
  const endTimeChange: DatePickerProps['onChange'] = (date, dateString) => {
    console.log(date, dateString);
    setEndTime(date)
  };
  // 订单状态更改
  const orderStatusChange = (value: string) => {
    console.log(`selected ${value}`);
    setOrderStatus(value)
  }
  // 点击搜索
  const onSearch = () => {
    setPage(1)
    console.log(startTime,endTime,orderStatus);
  }
  // 初始化搜索条件
  const init = () => {
    setPage(1)
    setStartTime(undefined)
    setEndTime(undefined)
    setOrderStatus(undefined)
  }
  // 点击清除
  const clearKeyWords = () => {
    init()
  }
  interface DataType {
    index?: number
    order: string
    name: string
    price: string
    status: string
    time1: string
    time2: string
  }

  const data: DataType[] = [
    {

      order: '123111111111',
      name: '后台管理系统',
      price: '5.00',
      status: '过户',
      time1: '2020-04-19 15:42:21',
      time2: '2020-04-19 15:42:21',
    },
    {

      order: '12345',
      name: '后台管理系统',
      price: '5.00',
      status: '过户',
      time1: '2020-04-19 15:42:21',
      time2: '2020-04-19 15:42:21',
    },
    {
      order: '1235678',
      name: '后台管理系统',
      price: '5.00',
      status: '过户',
      time1: '2020-04-19 15:42:21',
      time2: '2020-04-19 15:42:21',
    },

  ];



  return (
    <div className='trading-goods' style={{ height: `${height}px`, overflow: 'hidden' }}>
      {/* {contextHolder} */}
      <div className='trading-goods-search'>
        <DatePicker placeholder="开始时间"
          style={{ width: 198, height: 36, marginRight: 12 }}
          format={dateFormat}
          locale={locale}
          onChange={startTimeChange}
          value={startTime}
        />
        <DatePicker placeholder="结束时间"
          style={{ width: 198, height: 36, marginRight: 12 }}
          format={dateFormat}
          locale={locale}
          onChange={endTimeChange}
          value={endTime}
        />
        <Select
          placeholder='选择订单状态'
          style={{ width: 198, height: 36, marginRight: 12 }}
          onChange={orderStatusChange}
          options={[
            { value: 'xixi', label: '嘻嘻' },
            { value: 'hehe', label: '呵呵' },
          ]}
          value={orderStatus}
        />
        <Button type="primary"
          style={{
            height: 36,
            // backgroundColor: '#FF9F08' 
          }}

          icon={<SearchOutlined />}
          onClick={onSearch}
          >
          搜索
        </Button>
        <Button
          style={{
            height: 36,
            marginLeft: 10,
            // backgroundColor: '#FF9F08'
          }}
          icon={<ClearOutlined />}
          onClick={clearKeyWords}
          >
          清除
        </Button>
      </div>
      <div className='trading-goods-table'>
        {/* 表格 */}
        {data.length == 0 ? (
          <div className='nodata' style={{ height: `${height - 93}px` }}>
            <Empty
              description={
                '暂无数据'
              } />
          </div>) : (
          <div>
            <div style={{ height: `${height - 130}px` }}>
              <Table
                scroll={{ y: `${height - 190}px` }}
                dataSource={data}
                // pagination={{
                //   defaultPageSize: 10, // 设置默认一页显示 5 条数据
                // }}
                pagination={false} // 不显示分页
                style={{ textAlign: 'center' }} // 设置表格内容居中显示
                rowKey="order" // 指定数据项的唯一标识符
              >
                <Column title="序号"
                  width={70}
                  render={(_text, _record, index: number) => (
                    index + 1
                  )} align="center" />
                <Column
                  title="订单编号"
                  dataIndex="order"
                  align="center"
                />
                <Column
                  title="软著名称"
                  dataIndex="name"
                  align="center"
                  render={(text) => (
                    <span style={{ color: '#1B8BD2', fontSize: '16px', fontWeight: '700' }}>{text}</span>
                  )}
                />
                <Column title="订单价格" dataIndex="price" align="center"
                  render={(text) => (
                    <span style={{ color: '#FF5D15', fontSize: '24px', fontWeight: '700' }}>{text}</span>
                  )} />
                <Column title="订单状态" dataIndex="status" align="center" />
                <Column title="下单时间" dataIndex="time1" align="center" />
                <Column title="付款时间" dataIndex="time2" align="center" />
                {/* <Column title="实名认证状态" dataIndex="address" key="key" /> */}
                <Column
                  align="center"
                  title="操作"
                  render={(_text, record: any) => (
                    <Space size="middle">
                      <span className='trading-goods-table-btn' onClick={() => {
                        console.log(record.order);

                      }}>补充资料</span>
                    </Space>
                  )}
                />
              </Table>
            </div>
            {/* defaultCurrent: 默认当前页数  total:数据总数 defaultPageSize:'页面显示几条'  */}
            <div className='product-release-pagination' >
              <Pagination defaultCurrent={page} total={20} defaultPageSize={10} onChange={(page) => {
                console.log(page)
                setPage(page)
              }} />
            </div>
          </div>
        )}
      </div>
    </div>
  )
}


